@@ -11,9 +11,9 @@ def need_role(role=None, async=False):
         @functools.wraps(method)
         def wrapper(self, *args, **kwargs):
             if not self.current_user:
-                raise ServerError('not_auth')
+                raise ServerError(ServerError.AUTH_REQUIRED)
             elif self.current_user.role not in role:
-                raise ServerError('role_forbidden')
+                raise ServerError(ServerError.ROLE_FORBIDDEN)
             return method(self, *args, **kwargs)
 
         @functools.wraps(method)
@@ -21,9 +21,9 @@ def need_role(role=None, async=False):
         def async_wrapper(self, *args, **kwargs):
             current_user = yield self.current_user
             if not current_user:
-                raise ServerError('not_auth')
+                raise ServerError(ServerError.AUTH_REQUIRED)
             elif current_user.role not in role:
-                raise ServerError('role_forbidden')
+                raise ServerError(ServerError.ROLE_FORBIDDEN)
             yield method(self, *args, **kwargs)
 
         if async:
@@ -34,7 +34,7 @@ def need_role(role=None, async=False):
     return generator
 
 
-def need_not_role(role=None, error_code='ok', async=False):
+def need_not_role(role=None, error_status=ServerError.OK, async=False):
     if not role:
         role = []
 
@@ -42,7 +42,7 @@ def need_not_role(role=None, error_code='ok', async=False):
         @functools.wraps(method)
         def wrapper(self, *args, **kwargs):
             if self.current_user and self.current_user.role in role:
-                raise ServerError(error_code)
+                raise ServerError(error_status)
             return method(self, *args, **kwargs)
 
         @functools.wraps(method)
@@ -50,7 +50,7 @@ def need_not_role(role=None, error_code='ok', async=False):
         def async_wrapper(self, *args, **kwargs):
             current_user = yield self.current_user
             if current_user and current_user.role in role:
-                raise ServerError(error_code)
+                raise ServerError(error_status)
             yield method(self, *args, **kwargs)
 
         if async:
@@ -69,9 +69,9 @@ def need_is_approved(role=None):
         @functools.wraps(method)
         def wrapper(self, *args, **kwargs):
             if not self.current_user:
-                raise ServerError('not_auth')
+                raise ServerError(ServerError.AUTH_REQUIRED)
             elif self.current_user.role in role and self.current_user.is_approved is not True:
-                raise ServerError('forbidden')
+                raise ServerError(ServerError.FORBIDDEN)
             return method(self, *args, **kwargs)
 
         return wrapper
@@ -88,7 +88,7 @@ def need_is_active(role=None):
         def wrapper(self, *args, **kwargs):
             if self.current_user and self.current_user.role in role:
                 if self.current_user.is_active is not True:
-                    raise ServerError('account_not_active')
+                    raise ServerError(ServerError.ACCOUNT_INACTIVE)
             return method(self, *args, **kwargs)
 
         return wrapper
@@ -100,7 +100,7 @@ def authenticated(method):
     @functools.wraps(method)
     def wrapper(self, *args, **kwargs):
         if not self.current_user:
-            raise ServerError('not_auth')
+            raise ServerError(ServerError.AUTH_REQUIRED)
         return method(self, *args, **kwargs)
 
     return wrapper
@@ -110,7 +110,7 @@ def not_authenticated(method):
     @functools.wraps(method)
     def wrapper(self, *args, **kwargs):
         if self.current_user:
-            raise ServerError('auth_yet')
+            raise ServerError(ServerError.AUTH_NOT_REQUIRED)
         return method(self, *args, **kwargs)
 
     return wrapper
