@@ -1,14 +1,15 @@
-from mongoengine import document
+from mongoengine import Document
 from tornkts.mixins.to_dict_mixin import ToDictMixin
 from tornkts.mixins.validate_mixin import ValidateMixin
 
 
-class BaseDocument(ToDictMixin, ValidateMixin, document.Document):
+class BaseDocument(ToDictMixin, ValidateMixin, Document):
     meta = {
         'allow_inheritance': True,
-        'abstract': True
+        'abstract': True,
+        'strict': False
     }
 
     def get_id(self):
         return str(self.pk)
-        
\ No newline at end of file
+
