@@ -1,5 +1,5 @@
 from mongoengine import StringField
-from tornkts.base.mongodb import BaseDocument
+from tornkts.base.mongodb.base_document import BaseDocument
 
 
 class FileDocument(BaseDocument):
@@ -16,4 +16,4 @@ class FileDocument(BaseDocument):
             "file_id": self.file_id,
             "file_url": self.file_url,
             "id": self.get_id()
-        }
\ No newline at end of file
+        }
