@@ -1,6 +1,8 @@
 from mongoengine import ValidationError
+
 from tornkts.base.server_response import ServerError
 
+
 class ValidateMixin(object):
     def validate_model(self, prefix=None):
         if prefix is not None:
@@ -11,6 +13,6 @@ class ValidateMixin(object):
             self.validate()
         except ValidationError as e:
             field = e.errors.keys().pop()
-            raise ServerError('invalid_param',
+            raise ServerError(ServerError.INVALID_PARAMETER,
                               field=prefix + str(field),
                               field_problem=ServerError.FIELD_INVALID_FORMAT)
\ No newline at end of file
